@@ -55,10 +55,7 @@ mod app;
 mod bpf_program;
 mod helpers;
 mod pid_iter {
-    include!(concat!(
-        env!("CARGO_MANIFEST_DIR"),
-        "/src/bpf/pid_iter.skel.rs"
-    ));
+    include!(concat!(env!("OUT_DIR"), "/pid_iter.skel.rs"));
 }
 
 const TABLE_FOOTER: &str =
@@ -89,7 +86,11 @@ const TABLE_FOOTER_HEIGHT: u16 = 1; // derived from `TABLE_FOOTER`
     about = env!("CARGO_PKG_DESCRIPTION"),
     override_usage = "sudo bpftop"
 )]
-struct Bpftop {}
+struct Bpftop {
+    /// Delay between screen refreshes (seconds)
+    #[arg(short = 'd', long = "delay", default_value = "1", value_parser = clap::value_parser!(u64).range(1..3600))]
+    delay: u64,
+}
 
 impl From<&BpfProgram> for Row<'_> {
     fn from(bpf_program: &BpfProgram) -> Self {
@@ -127,26 +128,23 @@ impl TerminalManager {
 impl Drop for TerminalManager {
     fn drop(&mut self) {
         execute!(self.terminal.backend_mut(), LeaveAlternateScreen)
-            .unwrap_or_else(|e| eprintln!("Error leaving alternate screen: {:?}", e));
-        disable_raw_mode().unwrap_or_else(|e| eprintln!("Error disabling raw mode: {:?}", e));
+            .unwrap_or_else(|e| eprintln!("Error leaving alternate screen: {e:?}"));
+        disable_raw_mode().unwrap_or_else(|e| eprintln!("Error disabling raw mode: {e:?}"));
         self.terminal
             .show_cursor()
-            .unwrap_or_else(|e| eprintln!("Error showing cursor: {:?}", e));
+            .unwrap_or_else(|e| eprintln!("Error showing cursor: {e:?}"));
     }
 }
 
 fn main() -> Result<()> {
-    let _ = Bpftop::parse();
+    let args = Bpftop::parse();
 
     if !nix::unistd::Uid::current().is_root() {
         return Err(anyhow!("This program must be run as root"));
     }
 
     // Initialize the journald layer or ignore if not available
-    let journald_layer = match tracing_journald::layer() {
-        Ok(layer) => Some(layer),
-        Err(_) => None,
-    };
+    let journald_layer = tracing_journald::layer().ok();
 
     // Initialize the tracing subscriber with the journald layer
     let registry = tracing_subscriber::registry()
@@ -186,8 +184,7 @@ fn main() -> Result<()> {
             info!("BPF stats already enabled via procfs");
         } else {
             fs::write(PROCFS_BPF_STATS_ENABLED, b"1").context(format!(
-                "Failed to enable BPF stats via {}",
-                PROCFS_BPF_STATS_ENABLED
+                "Failed to enable BPF stats via {PROCFS_BPF_STATS_ENABLED}"
             ))?;
             stats_enabled_via_procfs = true;
             info!("Enabled BPF stats via procfs");
@@ -199,7 +196,7 @@ fn main() -> Result<()> {
     panic::set_hook(Box::new(move |panic_info| {
         if stats_enabled_via_procfs {
             if let Err(err) = procs_bfs_stats_disable() {
-                eprintln!("Failed to disable BPF stats via procfs: {:?}", err);
+                eprintln!("Failed to disable BPF stats via procfs: {err:?}");
             }
         }
 
@@ -210,7 +207,7 @@ fn main() -> Result<()> {
     let mut terminal_manager = TerminalManager::new()?;
 
     // create app and run the draw loop
-    let app = App::new();
+    let app = App::new(args.delay);
     app.start_background_thread(iter_link);
     let res = run_draw_loop(&mut terminal_manager.terminal, app);
 
@@ -229,15 +226,14 @@ fn main() -> Result<()> {
 
 fn procs_bfs_stats_disable() -> Result<()> {
     fs::write(PROCFS_BPF_STATS_ENABLED, b"0").context(format!(
-        "Failed to disable BPF stats via {}",
-        PROCFS_BPF_STATS_ENABLED
+        "Failed to disable BPF stats via {PROCFS_BPF_STATS_ENABLED}"
     ))?;
     Ok(())
 }
 
 fn procfs_bpf_stats_is_enabled() -> Result<bool> {
     fs::read_to_string(PROCFS_BPF_STATS_ENABLED)
-        .context(format!("Failed to read from {}", PROCFS_BPF_STATS_ENABLED))
+        .context(format!("Failed to read from {PROCFS_BPF_STATS_ENABLED}"))
         .map(|value| value.trim() == "1")
 }
 
@@ -357,7 +353,7 @@ fn render_graphs(f: &mut Frame, app: &mut App, area: Rect) {
     let mut avg_cpu = 0.0;
     let mut avg_eps = 0.0;
     let mut avg_runtime = 0.0;
-    if data_buf.len() > 0 {
+    if !data_buf.is_empty() {
         avg_cpu = total_cpu / data_buf.len() as f64;
         avg_eps = total_eps as f64 / data_buf.len() as f64;
         avg_runtime = total_runtime as f64 / data_buf.len() as f64;
